@@ -47,11 +47,29 @@ class Comments:
         buffer = {}
 
         for i in self.comments:
-            if i.peer:
-                buffer[i.peer] = buffer.get(i.peer, 0) + 1
+            _peer = i.peer
+            if _peer:
+                buffer[_peer] = buffer.get(_peer, 0) + 1
 
         return Counter(buffer).most_common(x)
 
+    @property
+    def peerToCommentCount(self) -> Dict[str, int]:
+        '''
+            Keeps count for which peer ( facebook profile ) is 
+            associated with how many comments.
+        '''
+        _buffer = {}
+
+        for i in self.comments:
+            _peer = i.peer
+            if not _peer:
+                continue
+
+            _buffer[_peer] = _buffer.get(_peer, 0) + 1
+
+        return _buffer
+
     @staticmethod
     def fromJSON(src: str) -> Comments:
         '''
